      subroutine ph_swconst(salt,rsw,tbohw,so4w,ssum,caw)
C-------------------------------------------------------------------
C PH_SWCONST $Revision: 1.0 $ $Date: 1998/12/07 $
C
C USAGE: 
C     double precision salt,rsw,tbohw,so4w,ssum,caw
C     call ph_swconst(salt,rsw,tbohw,so4w,ssum,caw)
C   SEE ph_test.f FOR DETAILS OF USING THIS PROGRAM!!!!!!!!!!!!!!!
C
C DESCRIPTION:
C  calculate concentrations of conservative species (change these 
C  to appropriate values if the porewater is not seawater based.)
C
C INPUT:
C  salt  : salinity of seawater at the specific location [PSU]
C  rsw   : density of seawater at the specific location [kg/m^3]
C
C OUTPUT:
C  ssum  : sum concentration of the conservative species in seawater
C  tbohw : concentration of total borate in seawater
C  caw   : concentration of total calcite in seawater
C  so4w  : concentration of total sulfate in seawater
C
C ORIGINAL AUTHOR OF THE FORTRAN VERSION: 
C   Bernard Boudreau 
C   Dept. Oceanography
C   Dalhousie University
C   Halifax, NS B3H 4J1,Canada
C   bernie@boudreau.ocean.dal.ca
C MINOR CHANGES BY:
C   Roger Luff and Matthias Haeckel 98-12-07
C   GEOMAR Research Centre for Marine Geosciences
C   Wischhofstr. 1-3, D-24148 Kiel, Germany
C   visumod@technologist.com
C
C DISCLAIMER:
C   This software is provided "as it is" without warranty of any kind.
C
C REFERENCES:
C   Boudreau B. P. (1996) A method-of-lines code for carbon and
C   nutrient diagenesis in aquatic sediments.Computers & Geosciences
C   22(5), 479-496.
C   Luff, Haeckel and Wallmann (submitted) "Robust and fast FORTRAN
C   and MATLAB libraries to calculate pH distributions in
C   marine systems", Computers & Geosciences.
C-------------------------------------------------------------------

      implicit none
      double precision chl, rsw, ccl, cna, cmg, ck, csr, cbr,refs
      double precision cf, cli, crb,salt,tbohw,so4w,ssum,caw

C     CALCULATE CONCENTRATIONS OF CONSERVATIVE SPECIES
C     (Change these to appropriate values if the porewater
C     is not seawater based.)
      REFS= 3.5D+01
      CHL = salt/1.80655D+00
      CCL = CHL*0.0281756D+00*RSW
      CNA = CHL*0.0242077D+00*RSW
      CMG = CHL*0.0027262D+00*RSW
      CAW = CHL*0.0005307D+00*RSW
      CK  = CHL*0.0005268D+00*RSW
      CSR = CHL*0.0000047D+00*RSW
      so4w = CHL*0.00145753*RSW

      CBR = CHL*0.0000434*RSW
      CF  = CHL*0.0000035*RSW
      tbohw = 1.212D-05*salt*RSW
      CLI = 0.0265*salt/REFS
      CRB = 0.00135*salt/REFS
      SSUM = (CNA+CK+CLI+CRB+2.0D+00*(CMG+CSR))-(CCL+CF+CBR)
      return
      end

