% PH_INFO  
%   Computational routines for the calculation of the pH and the 
%   concentrations of the dissociated species.
%
% AUTHORS: 
%   Roger Luff 98-12-07
%   GEOMAR Research Center for Marine Geosciences
%   Wischhofstr. 1-3, D-24148 Kiel, Germany
%   visumod@technologist.com
%   Marked parts are from
%   Bernard Boudreau 
%   Dept. Oceanography 
%   Dalhousie University
%   Halifax, NS B3H 4J1,Canada 
%   bernie@boudreau.ocean.dal.ca
%
% RELEASE:
%    PH-LIBRARY Version 1.0
%    $Revision: 1.0 $  $Date: 1998/12/07 $
%    Copyright (C) GEOMAR, Roger Luff, 1998.
%
% DESCRIPTION:
%    The PH-LIBRARY is a toolkit of MATLAB routines for calculating the
%    pH and the concentrations of the dissociated species. They are 
%    a self contained library and are extremely easy to use and will 
%    run on all computers that support MATLAB. It should also be
%    mentioned that the PH-LIBRARY is free of charge.  
%
% MATLAB:
%    For information on MATLAB contact info@mathworks.com
%
% DISCLAIMER OF WARRANTY AND LIMITS OF LIABILITY:
%   This software is provided "as it is" without warranty of any kind.
%   The authors of these programs have used their best efforts in 
%   preparing this material. These efforts include the development, 
%   research, and testing of the theories and programs to determine 
%   their effectiveness. The authors make no warranties of any kind, 
%   expressed or implied, with regard to both the programs and the 
%   documentation, which includes, without limitation, warranties of 
%   merchantability or fitness for a particular purpose. No liability 
%   is accepted in any event for any damages, including incidental 
%   or consequential damages, lost profits, cost of lost data or 
%   program material, or otherwise in connection with or arising out 
%   of the furnishing, performance, or use of the programs.
%
% REFERENCES:
%   Boudreau B. P. (1996) A method-of-lines code for carbon and 
%   nutrient diagenesis in aquatic sediments.Computers & Geosciences
%   22(5), 479-496.
%   Luff R., Haeckel M. and Wallmann K. (submitted) "Robust and fast FORTRAN
%   and MATLAB libraries to calculate pH distributions in
%   marine systems", Computers & Geosciences.
%
%   The above reference (at least Luff et al.) is highly recommended 
%   as it fully describes the sources of algorithms. The reference 
%   is available from the authors.
%   Roger Luff
%   VISUMOD
%   Klosterstr. 103
%   24536 Neumuenster
%   Germany
%   (visumod@technologist.com)


%
% IMPROVEMENTS AND SUGGESTIONS:
%   Please report any bugs so we update the master set of routines.
%   When reporting bugs please send a subset of the data you are
%   using, a diary of your MATLAB session and the results that you
%   think you should be getting. You MUST also send the release
%   version and date of the PH-LIBRARY that you are using.
%   If you have another routine that would be a useful addition
%   then please send them to us. Of course, copyright will stay 
%   with you (the author).
%
% COMMENTS:
%   We would also be interested in what areas of research and what
%   uses you have found for this library - very important for
%   resources to be made available to maintain the library.
%  HELP:
%    The autors will help in case of problems, please send us an
%    e-mail with an exact description of your problem, send uns a
%    description of your system/MATLAB-version and if necessary a 
%    part of your data which is responsible for the problem. We
%    will try our best.......
%
% UPDATES:
%   The newest code will be placed on our Web site:
%   http://www.geomar.de
%
% INSTALLATION:
%   We suggest you place all the PH-LIBRARY routines in a directory
%   called ph and set your MATLAB path to that directory.  
%   See the MATLAB command "help path" for more details.
%
% ACKNOWLEDGEMENTS:
%    This info file is mainly based on the information file from
%    the SEAWATER Library from Phillip P. Morgan
%    CSIRO, (morgan@ml.csiro.au)
%
% LIST OF ROUTINES in this package:
%
%     ph_density   Calculate the density of seawater
%     ph_eqadvan   pH-Calculation using advancement approach
%     ph_eqalk     pH-Calculation with alkalinity conservation
%     ph_eqcharge  pH-Calculation with charge conservation
%     ph_font      Set the font and size for the plots
%     ph_info      Information on the PH-LIBRARY library
%     ph_swconst   Calculate the concentration of conservative species
%     ph_tdconst   Calculate the thermodynamic constants
%
% LIST OF EXAMPLES in this package:
%
%     pic_advan    Creates Fig. 2 in Luff et al. using the advancement
%     pic_alk      Creates Fig. 1 in Luff et al. using the alkalinity
%     pic_charge   Creates a Fig. like 1 and 2 using the charge approach
%     tab_comp     Creates the resultes in Tab. 1 in Luff et al.
%     testall      Will call all samples.

more on
help ph_info
more off
return
%--------------------------------------------------------------------
